==> haskell-data-checked-0.3-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-checked.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-checked
version: 0.3
id: data-checked-0.3-GTvWanGmK17C2dYAqu1wOU
key: data-checked-0.3-GTvWanGmK17C2dYAqu1wOU
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-checked
synopsis: Type-indexed runtime-checked properties
description:
    This package provides a (phantom) type-indexed newtype evidence-wrapper for
    values that are checked to satisfy the property associated with the type.
category: Data
abi: 8c7962579ec7b2623b806381e898f089
exposed: True
exposed-modules:
    Data.Checked Data.Checked.Strict
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-checked-0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-checked-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/data-checked-0.3
hs-libraries: HSdata-checked-0.3-GTvWanGmK17C2dYAqu1wOU
depends:
    base-4.11.1.0 deepseq-1.4.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
haddock-interfaces: /usr/share/doc/haskell-data-checked/html/data-checked.haddock
haddock-html: /usr/share/doc/haskell-data-checked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-checked-0.3-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-checked.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-checked
version: 0.3
id: data-checked-0.3-Co0QNKLSvAXGWCJmpJNVMt
key: data-checked-0.3-Co0QNKLSvAXGWCJmpJNVMt
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-checked
synopsis: Type-indexed runtime-checked properties
description:
    This package provides a (phantom) type-indexed newtype evidence-wrapper for
    values that are checked to satisfy the property associated with the type.
category: Data
abi: 112a071b75dc7a00370f9d7b70824946
exposed: True
exposed-modules:
    Data.Checked Data.Checked.Strict
import-dirs: /usr/lib/ghc-8.6.1/site-local/data-checked-0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/data-checked-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/data-checked-0.3
hs-libraries: HSdata-checked-0.3-Co0QNKLSvAXGWCJmpJNVMt
depends:
    base-4.12.0.0 deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-data-checked/html/data-checked.haddock
haddock-html: /usr/share/doc/haskell-data-checked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
